from common import UpgradeContext
from conduit_ansible_api import AnsibleRunner
import conduit_config

from log_config import logger


class CertificateInstaller:

    def __init__(self, email, conduit_fqdn, ctx: UpgradeContext):
        self._email = email
        self._fqdn = conduit_fqdn
        self.upgrade_context = ctx

    def try_install(self):
        install_bp_certs_playbook = conduit_config.get_ansible_script_location(self.upgrade_context.run_id(),
                                                   playbook_name="install-bp-certs-playbook.yml")

        logger.info("Starting LetsEncrypt certificate installation for conduit_fqdn=%s using %s ",
                    self._fqdn, install_bp_certs_playbook)

        extra_var = dict(self.upgrade_context.extra_vars() or dict())
        extra_var.update({"conduit_admin_email": self._email,
                          "conduit_fqdn": self._fqdn
                          }
                         )
        local_hosts_inventory = conduit_config.get_ansible_inventory(self.upgrade_context.run_id())
        ansible_installer = AnsibleRunner(_playbook_path=install_bp_certs_playbook, inventory_file=local_hosts_inventory,
                                          extra_vars=extra_var)
        return_code = ansible_installer.run()
        if return_code != 0:
            raise CertificateInstallationError(ansible_return_code=return_code)

        logger.info("Certificates has been successfully installed")

        return return_code


class CertificateInstallationError(RuntimeError):

    def __init__(self, ansible_return_code, *args, **kwargs):
        super(RuntimeError, *args, **kwargs)
        self.return_code = ansible_return_code
