#!/usr/bin/env bash

RESOURCES_SCRIPT_PATH="$( cd -- "$(dirname "$BASH_SOURCE")" >/dev/null 2>&1 ; pwd -P )"
source ${RESOURCES_SCRIPT_PATH}/../../utils/functions.sh
source ${RESOURCES_SCRIPT_PATH}/../../utils/gcloud_functions.sh

load_gcloud_uninstall_parameters "$@"
load_gcloud_uninstall_parameters_input
set_gcloud_resources_names


#############################
# Validate input parameters #
#############################
echo "Validating parameters before deleting resources on Google Cloud Platform"
validate_gcloud_uninstall_parameters_are_defined
echo "Parameters validation successfully completed"

#
# Delete GCP resources
#
yes | gcloud compute forwarding-rules delete "${LB_FORWARD_RULE_HTTP}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute forwarding-rules delete "${LB_FORWARD_RULE_HTTPS}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute forwarding-rules delete "${LB_FORWARD_RULE_SSL}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute target-https-proxies delete "${LB_TARGET_PROXY_HTTPS}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute target-http-proxies delete "${LB_TARGET_PROXY_HTTP}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute target-ssl-proxies delete "${LB_TARGET_PROXY_SSL}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute url-maps delete "${LB_URL_MAPS_HTTP}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute url-maps delete "${LB_URL_MAPS_HTTPS}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute backend-services delete "${LB_BACKEND_SERVICE}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute backend-services delete "${LB_BACKEND_SERVICE_SSL}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute health-checks delete "${LB_HEALTH_CHECK}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute health-checks delete "${LB_HEALTH_CHECK_SSL}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute addresses delete "${LB_IP}" --global --project "${GCP_PROJECT_ID}"
yes | gcloud compute firewall-rules delete "${VNET_FIREWALL_HEALTH_CHECK}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute firewall-rules delete "${VNET_FIREWALL_ALLOW_INTERNAL}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute firewall-rules delete "${VNET_FIREWALL_ALLOW_EXTERNAL}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute firewall-rules delete "${VNET_FIREWALL_ALLOW_SSH}" --project "${GCP_PROJECT_ID}"

#Delete GCS bucket
BUCKET_NAME=$(gsutil ls -b gs://"${DEPLOYMENT_NAME}-gcs-*")
gsutil -m rm "${BUCKET_NAME}**"
gsutil rb -f "${BUCKET_NAME}"

yes | gcloud iam service-accounts delete "${GCS_IAM_USER}@${GCP_PROJECT_ID}.iam.gserviceaccount.com"

yes | gcloud compute instance-groups managed delete "${INSTANCE_VM_GROUP}" --region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute instance-templates delete "${INSTANCE_TEMPLATE}" --project "${GCP_PROJECT_ID}"

JUMPBOX_ZONE=$(gcloud compute zones list --filter="name=${DEPLOYMENT_REGION}" --format="get(name)" | awk -F/ '{print $NF}' | head -n 1)
yes | gcloud compute instances delete "${JUMPBOX_VM}" --zone="${JUMPBOX_ZONE}"

yes | gcloud compute addresses delete "${JUMPBOX_IP}" --region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"

yes | gcloud compute routers nats delete "${NAT}" --router="${ROUTER}" --router-region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute routers delete "${ROUTER}" --region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute addresses delete "${NAT_IP}" --region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"

yes | gcloud compute networks subnets delete "${VNET_SUBNET}" --region="${DEPLOYMENT_REGION}" --project "${GCP_PROJECT_ID}"
yes | gcloud compute networks delete "${VNET}" --project "${GCP_PROJECT_ID}"

echo ""
echo "####################################"
echo "Conduit was successfully uninstalled"
echo "####################################"
echo ""