version: '2.4'
services:
  conduit-worker:
    image: blueprint.azurecr.io/bpcs/conduit-worker:s3.2.0_h3.3.1
    labels:
      com.bpcs.conduit.displayName: "Conduit Worker"
    network_mode: host
    container_name: conduit-worker
    restart: on-failure
    mem_swappiness: 0
    healthcheck:
      test: [ "CMD-SHELL", "curl --silent --fail -o /dev/null  http://{{ ansible_default_ipv4.address }}:4081 || exit 1" ]
      interval: 30s
      timeout: 5s
      retries: 10
    environment:
      - SPARK_MASTER=spark://{{ spark_host }}:7077
      #Allocation Parameters
      - SPARK_WORKER_CORES={{ spark_worker_cores | default(8) }}
      - SPARK_WORKER_MEMORY={{ spark_worker_memory | default('23g') }}
      - SPARK_LOCAL_DIRS=/mnt/spark/local_dirs
      - SPARK_WORKER_DIR=/mnt/spark/work
      - SPARK_WORKER_OPTS=-Dspark.worker.cleanup.enabled=true -Dspark.worker.cleanup.interval=600 -Dspark.worker.cleanup.appDataTtl=86400 -Dspark.ui.proxyBase=/sparkui -Dspark.ui.reverseProxyUrl=/sparkui -Dspark.ui.reverseProxy=true
      - SPARK_WORKER_WEBUI_PORT=4081
      - SPARK_PUBLIC_DNS={{ ansible_default_ipv4.address }}
      - SPARK_LOCAL_IP={{ ansible_default_ipv4.address }}

      {% if conduit_fs_type == 'hdfs' %}
      #HDFS settings
      - FS_DEFAULTFS=hdfs://{{  groups[ 'conduit-master' ][0] | default(ansible_default_ipv4.address) }}:8020
      {% endif %}

    volumes:
      - {{ spark_work_dir | default('/mnt/spark/work') }}:/mnt/spark/work
      - {{ spark_local_dirs_mount | default('/mnt/spark/local_dirs') }}:/mnt/spark/local_dirs
      - {{ conduit_parquet_storage | default('/mnt/conduit_parquet_store') }}:/mnt/conduit_parquet_store
      - /etc/bpcs/docker/conduit/gcs/keyfile/:/etc/bpcs/docker/bde-server/gcs/keyfile/
